SCRIPT_NAME=mips
OUTPUT_FORMAT="ecoff-littlemips"
BIG_OUTPUT_FORMAT="ecoff-bigmips"
LITTLE_OUTPUT_FORMAT="ecoff-littlemips"
TARGET_PAGE_SIZE=0x1000000
ARCH=mips
TEXT_START_ADDR=0x80080000
DATA_ADDR=.
EMBEDDED=yes
