;# data.s	
;# checks all the data transfer instructions for MAXQ10
foo:
;	XCH			; Not in MAXQ10
	XCHN
	MOVE NUL, #01h
	MOVE NUL, AP
	MOVE NUL, APC
	MOVE NUL, PSF
	MOVE NUL, IC
	MOVE NUL, IMR
	MOVE NUL, SC
	MOVE NUL, IIR
	MOVE NUL, CKCN
	MOVE NUL, WDCN
	MOVE NUL, A[0]		;Just Check two boundary conditions
	MOVE NUL, A[15]   
	MOVE NUL, ACC
	MOVE NUL, A[AP]
	MOVE NUL, IP
	MOVE NUL, @SP--
	MOVE NUL, SP
	MOVE NUL, IV
	MOVE NUL, LC[0]
	MOVE NUL, LC[1]
	MOVE NUL, @BP[OFFS++]
	MOVE NUL, @BP[OFFS--]
	MOVE NUL, OFFS
	MOVE NUL, DPC
	MOVE NUL, GR
	MOVE NUL, GRL
	MOVE NUL, BP
	MOVE NUL, GRS
	MOVE NUL, GRH
	MOVE NUL, GRXL
	MOVE NUL, FP
	MOVE NUL, @DP[0]	
	MOVE NUL, @DP[1]	
	MOVE NUL, @DP[0]++		
	MOVE NUL, @DP[1]++
	MOVE NUL, @DP[0]--
	MOVE NUL, @DP[1]--
	MOVE AP, #01h
	MOVE AP, APC
	MOVE AP, PSF
	MOVE AP, IC
	MOVE AP, IMR
	MOVE AP, SC
	MOVE AP, IIR
	MOVE AP, CKCN
	MOVE AP, WDCN
	MOVE AP, A[0]		;Just Check two boundary conditions
	MOVE AP, A[15]   
	MOVE AP, ACC
	MOVE AP, A[AP]
	MOVE AP, IP
	MOVE AP, @SP--
	MOVE AP, SP
	MOVE AP, IV
	MOVE AP, LC[0]
	MOVE AP, LC[1]
	MOVE AP, @BP[OFFS++]
	MOVE AP, @BP[OFFS--]
	MOVE AP, OFFS
	MOVE AP, DPC
	MOVE AP, GR
	MOVE AP, GRL
	MOVE AP, BP
	MOVE AP, GRS
	MOVE AP, GRH
	MOVE AP, GRXL
	MOVE AP, FP
	MOVE AP, @DP[0]	
	MOVE AP, @DP[1]	
	MOVE AP, @DP[0]++		
	MOVE AP, @DP[1]++
	MOVE AP, @DP[0]--
	MOVE AP, @DP[1]--
	MOVE APC, #01h
	MOVE APC, AP
	MOVE APC, PSF
	MOVE APC, IC
	MOVE APC, IMR
	MOVE APC, SC
	MOVE APC, IIR
	MOVE APC, CKCN
	MOVE APC, WDCN
	MOVE APC, A[0]		;Just Check two boundary conditions
	MOVE APC, A[15]   
	MOVE APC, ACC
	MOVE APC, A[AP]
	MOVE APC, IP
	MOVE APC, @SP--
	MOVE APC, SP
	MOVE APC, IV
	MOVE APC, LC[0]
	MOVE APC, LC[1]
	MOVE APC, @BP[OFFS++]
	MOVE APC, @BP[OFFS--]
	MOVE APC, OFFS
	MOVE APC, DPC
	MOVE APC, GR
	MOVE APC, GRL
	MOVE APC, BP
	MOVE APC, GRS
	MOVE APC, GRH
	MOVE APC, GRXL
	MOVE APC, FP
	MOVE APC, @DP[0]	
	MOVE APC, @DP[1]	
	MOVE APC, @DP[0]++		
	MOVE APC, @DP[1]++
	MOVE APC, @DP[0]--
	MOVE APC, @DP[1]--
	MOVE PSF, #01h
	MOVE PSF, AP
	MOVE PSF, APC
	MOVE PSF, IC
	MOVE PSF, IMR
	MOVE PSF, SC
	MOVE PSF, IIR
	MOVE PSF, CKCN
	MOVE PSF, WDCN
	MOVE PSF, A[0]		;Just Check two boundary conditions
	MOVE PSF, A[15]   
	MOVE PSF, ACC
	MOVE PSF, A[AP]
	MOVE PSF, IP
	MOVE PSF, @SP--
	MOVE PSF, SP
	MOVE PSF, IV
	MOVE PSF, LC[0]
	MOVE PSF, LC[1]
	MOVE PSF, @BP[OFFS++]
	MOVE PSF, @BP[OFFS--]
	MOVE PSF, OFFS
	MOVE PSF, DPC
	MOVE PSF, GR
	MOVE PSF, GRL
	MOVE PSF, BP
	MOVE PSF, GRS
	MOVE PSF, GRH
	MOVE PSF, GRXL
	MOVE PSF, FP
	MOVE PSF, @DP[0]	
	MOVE PSF, @DP[1]	
	MOVE PSF, @DP[0]++		
	MOVE PSF, @DP[1]++
	MOVE PSF, @DP[0]--
	MOVE PSF, @DP[1]--
	MOVE IC, #01h
	MOVE IC, AP
	MOVE IC, APC
	MOVE IC, PSF
	MOVE IC, IMR
	MOVE IC, SC
	MOVE IC, IIR
	MOVE IC, CKCN
	MOVE IC, WDCN
	MOVE IC, A[0]		;Just Check two boundary conditions
	MOVE IC, A[15]   
	MOVE IC, ACC
	MOVE IC, A[AP]
	MOVE IC, IP
	MOVE IC, @SP--
	MOVE IC, SP
	MOVE IC, IV
	MOVE IC, LC[0]
	MOVE IC, LC[1]
	MOVE IC, @BP[OFFS++]
	MOVE IC, @BP[OFFS--]
	MOVE IC, OFFS
	MOVE IC, DPC
	MOVE IC, GR
	MOVE IC, GRL
	MOVE IC, BP
	MOVE IC, GRS
	MOVE IC, GRH
	MOVE IC, GRXL
	MOVE IC, FP
	MOVE IC, @DP[0]	
	MOVE IC, @DP[1]	
	MOVE IC, @DP[0]++		
	MOVE IC, @DP[1]++
	MOVE IC, @DP[0]--
	MOVE IC, @DP[1]--
	MOVE IMR, #01h
	MOVE IMR, AP
	MOVE IMR, APC
	MOVE IMR, PSF
	MOVE IMR, IC
	MOVE IMR, SC
	MOVE IMR, IIR
	MOVE IMR, CKCN
	MOVE IMR, WDCN
	MOVE IMR, A[0]		;Just Check two boundary conditions
	MOVE IMR, A[15]   
	MOVE IMR, ACC
	MOVE IMR, A[AP]
	MOVE IMR, IP
	MOVE IMR, @SP--
	MOVE IMR, SP
	MOVE IMR, IV
	MOVE IMR, LC[0]
	MOVE IMR, LC[1]
	MOVE IMR, @BP[OFFS++]
	MOVE IMR, @BP[OFFS--]
	MOVE IMR, OFFS
	MOVE IMR, DPC
	MOVE IMR, GR
	MOVE IMR, GRL
	MOVE IMR, BP
	MOVE IMR, GRS
	MOVE IMR, GRH
	MOVE IMR, GRXL
	MOVE IMR, FP
	MOVE IMR, @DP[0]	
	MOVE IMR, @DP[1]	
	MOVE IMR, @DP[0]++		
	MOVE IMR, @DP[1]++
	MOVE IMR, @DP[0]--
	MOVE IMR, @DP[1]--
	MOVE A[0], #01h
	MOVE A[0], AP
	MOVE A[0], APC
	MOVE A[0], PSF
	MOVE A[0], IC
	MOVE A[0], IMR
	MOVE A[0], SC
	MOVE A[0], IIR
	MOVE A[0], CKCN
	MOVE A[0], WDCN
	MOVE A[0], ACC
	MOVE A[0], A[AP]
	MOVE A[0], IP
	MOVE A[0], @SP--
	MOVE A[0], SP
	MOVE A[0], IV
	MOVE A[0], LC[0]
	MOVE A[0], LC[1]
	MOVE A[0], @BP[OFFS++]
	MOVE A[0], @BP[OFFS--]
	MOVE A[0], OFFS
	MOVE A[0], DPC
	MOVE A[0], GR
	MOVE A[0], GRL
	MOVE A[0], BP
	MOVE A[0], GRS
	MOVE A[0], GRH
	MOVE A[0], GRXL
	MOVE A[0], FP
	MOVE A[0], @DP[0]	
	MOVE A[0], @DP[1]	
	MOVE A[0], @DP[0]++		
	MOVE A[0], @DP[1]++
	MOVE A[0], @DP[0]--
	MOVE A[0], @DP[1]--
	MOVE ACC, #01h
	MOVE ACC, AP
	MOVE ACC, APC
	MOVE ACC, PSF
	MOVE ACC, IC
	MOVE ACC, IMR
	MOVE ACC, SC
	MOVE ACC, IIR
	MOVE ACC, CKCN
	MOVE ACC, WDCN
	MOVE ACC, A[0]		;Just Check two boundary conditions
	MOVE ACC, A[15]   
	MOVE ACC, IP
	MOVE ACC, @SP--
	MOVE ACC, SP
	MOVE ACC, IV
	MOVE ACC, LC[0]
	MOVE ACC, LC[1]
	MOVE ACC, @BP[OFFS++]
	MOVE ACC, @BP[OFFS--]
	MOVE ACC, OFFS
	MOVE ACC, DPC
	MOVE ACC, GR
	MOVE ACC, GRL
	MOVE ACC, BP
	MOVE ACC, GRS
	MOVE ACC, GRH
	MOVE ACC, GRXL
	MOVE ACC, FP
	MOVE ACC, @DP[0]	
	MOVE ACC, @DP[1]	
	MOVE ACC, @DP[0]++		
	MOVE ACC, @DP[1]++
	MOVE ACC, @DP[0]--
	MOVE ACC, @DP[1]--
	MOVE @++SP, #01h
	MOVE @++SP, AP
	MOVE @++SP, APC
	MOVE @++SP, PSF
	MOVE @++SP, IC
	MOVE @++SP, IMR
	MOVE @++SP, SC
	MOVE @++SP, IIR
	MOVE @++SP, CKCN
	MOVE @++SP, WDCN
	MOVE @++SP, A[0]		;Just Check two boundary conditions
	MOVE @++SP, A[15]   
	MOVE @++SP, ACC
	MOVE @++SP, A[AP]
	MOVE @++SP, IP
	MOVE @++SP, SP
	MOVE @++SP, IV
	MOVE @++SP, LC[0]
	MOVE @++SP, LC[1]
	MOVE @++SP, @BP[OFFS++]
	MOVE @++SP, @BP[OFFS--]
	MOVE @++SP, OFFS
	MOVE @++SP, DPC
	MOVE @++SP, GR
	MOVE @++SP, GRL
	MOVE @++SP, BP
	MOVE @++SP, GRS
	MOVE @++SP, GRH
	MOVE @++SP, GRXL
	MOVE @++SP, FP
	MOVE @++SP, @DP[0]	
	MOVE @++SP, @DP[1]	
	MOVE @++SP, @DP[0]++		
	MOVE @++SP, @DP[1]++
	MOVE @++SP, @DP[0]--
	MOVE @++SP, @DP[1]--
	MOVE SP, #01h
	MOVE SP, AP
	MOVE SP, APC
	MOVE SP, PSF
	MOVE SP, IC
	MOVE SP, IMR
	MOVE SP, SC
	MOVE SP, IIR
	MOVE SP, CKCN
	MOVE SP, WDCN
	MOVE SP, A[0]		;Just Check two boundary conditions
	MOVE SP, A[15]   
	MOVE SP, ACC
	MOVE SP, A[AP]
	MOVE SP, IP
	MOVE SP, IV
	MOVE SP, LC[0]
	MOVE SP, LC[1]
	MOVE SP, @BP[OFFS++]
	MOVE SP, @BP[OFFS--]
	MOVE SP, OFFS
	MOVE SP, DPC
	MOVE SP, GR
	MOVE SP, GRL
	MOVE SP, BP
	MOVE SP, GRS
	MOVE SP, GRH
	MOVE SP, GRXL
	MOVE SP, FP
	MOVE SP, @DP[0]	
	MOVE SP, @DP[1]	
	MOVE SP, @DP[0]++		
	MOVE SP, @DP[1]++
	MOVE SP, @DP[0]--
	MOVE SP, @DP[1]--
	MOVE IV, #01h
	MOVE IV, AP
	MOVE IV, APC
	MOVE IV, PSF
	MOVE IV, IC
	MOVE IV, IMR
	MOVE IV, SC
	MOVE IV, IIR
	MOVE IV, CKCN
	MOVE IV, WDCN
	MOVE IV, A[0]		;Just Check two boundary conditions
	MOVE IV, A[15]   
	MOVE IV, ACC
	MOVE IV, A[AP]
	MOVE IV, IP
	MOVE IV, @SP--
	MOVE IV, SP
	MOVE IV, IV
	MOVE IV, LC[0]
	MOVE IV, LC[1]
	MOVE IV, @BP[OFFS++]
	MOVE IV, @BP[OFFS--]
	MOVE IV, OFFS
	MOVE IV, DPC
	MOVE IV, GR
	MOVE IV, GRL
	MOVE IV, BP
	MOVE IV, GRS
	MOVE IV, GRH
	MOVE IV, GRXL
	MOVE IV, FP
	MOVE IV, @DP[0]	
	MOVE IV, @DP[1]	
	MOVE IV, @DP[0]++		
	MOVE IV, @DP[1]++
	MOVE IV, @DP[0]--
	MOVE IV, @DP[1]--
	MOVE LC[0], #01h
	MOVE LC[0], AP
	MOVE LC[0], APC
	MOVE LC[0], PSF
	MOVE LC[0], IC
	MOVE LC[0], IMR
	MOVE LC[0], SC
	MOVE LC[0], IIR
	MOVE LC[0], CKCN
	MOVE LC[0], WDCN
	MOVE LC[0], A[0]		;Just Check two boundary conditions
	MOVE LC[0], A[15]   
	MOVE LC[0], ACC
	MOVE LC[0], A[AP]
	MOVE LC[0], IP
	MOVE LC[0], @SP--
	MOVE LC[0], SP
	MOVE LC[0], IV
	MOVE LC[0], @BP[OFFS++]
	MOVE LC[0], @BP[OFFS--]
	MOVE LC[0], OFFS
	MOVE LC[0], DPC
	MOVE LC[0], GR
	MOVE LC[0], GRL
	MOVE LC[0], BP
	MOVE LC[0], GRS
	MOVE LC[0], GRH
	MOVE LC[0], GRXL
	MOVE LC[0], FP
	MOVE LC[0], @DP[0]	
	MOVE LC[0], @DP[1]	
	MOVE LC[0], @DP[0]++		
	MOVE LC[0], @DP[1]++
	MOVE LC[0], @DP[0]--
	MOVE LC[0], @DP[1]--
	MOVE @BP[OFFS], #01h
	MOVE @BP[OFFS], AP
	MOVE @BP[OFFS], APC
	MOVE @BP[OFFS], PSF
	MOVE @BP[OFFS], IC
	MOVE @BP[OFFS], IMR
	MOVE @BP[OFFS], SC
	MOVE @BP[OFFS], IIR
	MOVE @BP[OFFS], CKCN
	MOVE @BP[OFFS], WDCN
	MOVE @BP[OFFS], A[0]		;Just Check two boundary conditions
	MOVE @BP[OFFS], A[15]   
	MOVE @BP[OFFS], ACC
	MOVE @BP[OFFS], A[AP]
	MOVE @BP[OFFS], IP
	MOVE @BP[OFFS], @SP--
	MOVE @BP[OFFS], SP
	MOVE @BP[OFFS], IV
	MOVE @BP[OFFS], LC[0]
	MOVE @BP[OFFS], LC[1]
	MOVE @BP[OFFS], OFFS
	MOVE @BP[OFFS], DPC
	MOVE @BP[OFFS], GR
	MOVE @BP[OFFS], GRL
	MOVE @BP[OFFS], BP
	MOVE @BP[OFFS], GRS
	MOVE @BP[OFFS], GRH
	MOVE @BP[OFFS], GRXL
	MOVE @BP[OFFS], FP
	MOVE @BP[OFFS], @DP[0]	
	MOVE @BP[OFFS], @DP[1]	
	MOVE @BP[OFFS], @DP[0]++		
	MOVE @BP[OFFS], @DP[1]++
	MOVE @BP[OFFS], @DP[0]--
	MOVE @BP[OFFS], @DP[1]--
	MOVE @BP[++OFFS], #01h
	MOVE @BP[++OFFS], AP
	MOVE @BP[++OFFS], APC
	MOVE @BP[++OFFS], PSF
	MOVE @BP[++OFFS], IC
	MOVE @BP[++OFFS], IMR
	MOVE @BP[++OFFS], SC
	MOVE @BP[++OFFS], IIR
	MOVE @BP[++OFFS], CKCN
	MOVE @BP[++OFFS], WDCN
	MOVE @BP[++OFFS], A[0]		;Just Check two boundary conditions
	MOVE @BP[++OFFS], A[15]   
	MOVE @BP[++OFFS], ACC
	MOVE @BP[++OFFS], A[AP]
	MOVE @BP[++OFFS], IP
	MOVE @BP[++OFFS], SP
	MOVE @BP[++OFFS], IV
	MOVE @BP[++OFFS], LC[0]
	MOVE @BP[++OFFS], LC[1]
	MOVE @BP[++OFFS], OFFS
	MOVE @BP[++OFFS], DPC
	MOVE @BP[++OFFS], GR
	MOVE @BP[++OFFS], GRL
	MOVE @BP[++OFFS], BP
	MOVE @BP[++OFFS], GRS
	MOVE @BP[++OFFS], GRH
	MOVE @BP[++OFFS], GRXL
	MOVE @BP[++OFFS], FP
	MOVE @BP[++OFFS], @DP[0]	
	MOVE @BP[++OFFS], @DP[1]	
	MOVE @BP[++OFFS], @DP[0]--
	MOVE @BP[++OFFS], @DP[1]--
	MOVE @BP[--OFFS], #01h
	MOVE @BP[--OFFS], AP
	MOVE @BP[--OFFS], APC
	MOVE @BP[--OFFS], PSF
	MOVE @BP[--OFFS], IC
	MOVE @BP[--OFFS], IMR
	MOVE @BP[--OFFS], SC
	MOVE @BP[--OFFS], IIR
	MOVE @BP[--OFFS], CKCN
	MOVE @BP[--OFFS], WDCN
	MOVE @BP[--OFFS], A[0]		;Just Check two boundary conditions
	MOVE @BP[--OFFS], A[15]   
	MOVE @BP[--OFFS], ACC
	MOVE @BP[--OFFS], A[AP]
	MOVE @BP[--OFFS], IP
	MOVE @BP[--OFFS], SP
	MOVE @BP[--OFFS], IV
	MOVE @BP[--OFFS], LC[0]
	MOVE @BP[--OFFS], LC[1]
	MOVE @BP[--OFFS], OFFS
	MOVE @BP[--OFFS], DPC
	MOVE @BP[--OFFS], GR
	MOVE @BP[--OFFS], GRL
	MOVE @BP[--OFFS], BP
	MOVE @BP[--OFFS], GRS
	MOVE @BP[--OFFS], GRH
	MOVE @BP[--OFFS], GRXL
	MOVE @BP[--OFFS], FP
	MOVE @BP[--OFFS], @DP[0]	
	MOVE @BP[--OFFS], @DP[1]	
	MOVE OFFS, #01h
	MOVE OFFS, AP
	MOVE OFFS, APC
	MOVE OFFS, PSF
	MOVE OFFS, IC
	MOVE OFFS, IMR
	MOVE OFFS, SC
	MOVE OFFS, IIR
	MOVE OFFS, CKCN
	MOVE OFFS, WDCN
	MOVE OFFS, A[0]		;Just Check two boundary conditions
	MOVE OFFS, A[15]   
	MOVE OFFS, ACC
	MOVE OFFS, A[AP]
	MOVE OFFS, IP
	MOVE OFFS, @SP--
	MOVE OFFS, SP
	MOVE OFFS, IV
	MOVE OFFS, LC[0]
	MOVE OFFS, LC[1]
	MOVE OFFS, DPC
	MOVE OFFS, GR
	MOVE OFFS, GRL
	MOVE OFFS, BP
	MOVE OFFS, GRS
	MOVE OFFS, GRH
	MOVE OFFS, GRXL
	MOVE OFFS, FP
	MOVE OFFS, @DP[0]	
	MOVE OFFS, @DP[1]	
	MOVE OFFS, @DP[0]++		
	MOVE OFFS, @DP[1]++
	MOVE OFFS, @DP[0]--
	MOVE OFFS, @DP[1]--
	MOVE DPC, #01h
	MOVE DPC, AP
	MOVE DPC, APC
	MOVE DPC, PSF
	MOVE DPC, IC
	MOVE DPC, IMR
	MOVE DPC, SC
	MOVE DPC, IIR
	MOVE DPC, CKCN
	MOVE DPC, WDCN
	MOVE DPC, A[0]		;Just Check two boundary conditions
	MOVE DPC, A[15]   
	MOVE DPC, ACC
	MOVE DPC, A[AP]
	MOVE DPC, IP
	MOVE DPC, @SP--
	MOVE DPC, SP
	MOVE DPC, IV
	MOVE DPC, LC[0]
	MOVE DPC, LC[1]
	MOVE DPC, @BP[OFFS++]
	MOVE DPC, @BP[OFFS--]
	MOVE DPC, OFFS
	MOVE DPC, GR
	MOVE DPC, GRL
	MOVE DPC, BP
	MOVE DPC, GRS
	MOVE DPC, GRH
	MOVE DPC, GRXL
	MOVE DPC, FP
	MOVE DPC, @DP[0]	
	MOVE DPC, @DP[1]	
	MOVE DPC, @DP[0]++		
	MOVE DPC, @DP[1]++
	MOVE DPC, @DP[0]--
	MOVE DPC, @DP[1]--
	MOVE GR, #01h
	MOVE GR, AP
	MOVE GR, APC
	MOVE GR, PSF
	MOVE GR, IC
	MOVE GR, IMR
	MOVE GR, SC
	MOVE GR, IIR
	MOVE GR, CKCN
	MOVE GR, WDCN
	MOVE GR, A[0]		;Just Check two boundary conditions
	MOVE GR, A[15]   
	MOVE GR, ACC
	MOVE GR, A[AP]
	MOVE GR, IP
	MOVE GR, @SP--
	MOVE GR, SP
	MOVE GR, IV
	MOVE GR, LC[0]
	MOVE GR, LC[1]
	MOVE GR, @BP[OFFS++]
	MOVE GR, @BP[OFFS--]
	MOVE GR, OFFS
	MOVE GR, DPC
	MOVE GR, GRL
	MOVE GR, BP
	MOVE GR, GRS
	MOVE GR, GRH
	MOVE GR, GRXL
	MOVE GR, FP
	MOVE GR, @DP[0]	
	MOVE GR, @DP[1]	
	MOVE GR, @DP[0]++		
	MOVE GR, @DP[1]++
	MOVE GR, @DP[0]--
	MOVE GR, @DP[1]--
	MOVE GRL, #01h
	MOVE GRL, AP
	MOVE GRL, APC
	MOVE GRL, PSF
	MOVE GRL, IC
	MOVE GRL, IMR
	MOVE GRL, SC
	MOVE GRL, IIR
	MOVE GRL, CKCN
	MOVE GRL, WDCN
	MOVE GRL, A[0]		;Just Check two boundary conditions
	MOVE GRL, A[15]   
	MOVE GRL, ACC
	MOVE GRL, A[AP]
	MOVE GRL, IP
	MOVE GRL, @SP--
	MOVE GRL, SP
	MOVE GRL, IV
	MOVE GRL, LC[0]
	MOVE GRL, LC[1]
	MOVE GRL, @BP[OFFS++]
	MOVE GRL, @BP[OFFS--]
	MOVE GRL, OFFS
	MOVE GRL, DPC
	MOVE GRL, GR
	MOVE GRL, BP
	MOVE GRL, GRS
	MOVE GRL, GRH
	MOVE GRL, GRXL
	MOVE GRL, FP
	MOVE GRL, @DP[0]	
	MOVE GRL, @DP[1]	
	MOVE GRL, @DP[0]++		
	MOVE GRL, @DP[1]++
	MOVE GRL, @DP[0]--
	MOVE GRL, @DP[1]--
	MOVE BP, #01h
	MOVE BP, AP
	MOVE BP, APC
	MOVE BP, PSF
	MOVE BP, IC
	MOVE BP, IMR
	MOVE BP, SC
	MOVE BP, IIR
	MOVE BP, CKCN
	MOVE BP, WDCN
	MOVE BP, A[0]		;Just Check two boundary conditions
	MOVE BP, A[15]   
	MOVE BP, ACC
	MOVE BP, A[AP]
	MOVE BP, IP
	MOVE BP, @SP--
	MOVE BP, SP
	MOVE BP, IV
	MOVE BP, LC[0]
	MOVE BP, LC[1]
	MOVE BP, @BP[OFFS++]
	MOVE BP, @BP[OFFS--]
	MOVE BP, OFFS
	MOVE BP, DPC
	MOVE BP, GR
	MOVE BP, GRL
	MOVE BP, GRS
	MOVE BP, GRH
	MOVE BP, GRXL
	MOVE BP, FP
	MOVE BP, @DP[0]	
	MOVE BP, @DP[1]	
	MOVE BP, @DP[0]++		
	MOVE BP, @DP[1]++
	MOVE BP, @DP[0]--
	MOVE BP, @DP[1]--
	MOVE @DP[0], #01h
	MOVE @DP[0], AP
	MOVE @DP[0], APC
	MOVE @DP[0], PSF
	MOVE @DP[0], IC
	MOVE @DP[0], IMR
	MOVE @DP[0], SC
	MOVE @DP[0], IIR
	MOVE @DP[0], CKCN
	MOVE @DP[0], WDCN
	MOVE @DP[0], A[0]		;Just Check two boundary conditions
	MOVE @DP[0], A[15]   
	MOVE @DP[0], ACC
	MOVE @DP[0], A[AP]
	MOVE @DP[0], IP
	MOVE @DP[0], @SP--
	MOVE @DP[0], SP
	MOVE @DP[0], IV
	MOVE @DP[0], LC[0]
	MOVE @DP[0], LC[1]
	MOVE @DP[0], @BP[OFFS++]
	MOVE @DP[0], @BP[OFFS--]
	MOVE @DP[0], OFFS
	MOVE @DP[0], DPC
	MOVE @DP[0], GR
	MOVE @DP[0], GRL
	MOVE @DP[0], BP
	MOVE @DP[0], GRS
	MOVE @DP[0], GRH
	MOVE @DP[0], GRXL
	MOVE @DP[0], FP
	MOVE @++DP[0], #01h
	MOVE @++DP[0], AP
	MOVE @++DP[0], APC
	MOVE @++DP[0], PSF
	MOVE @++DP[0], IC
	MOVE @++DP[0], IMR
	MOVE @++DP[0], SC
	MOVE @++DP[0], IIR
	MOVE @++DP[0], CKCN
	MOVE @++DP[0], WDCN
	MOVE @++DP[0], A[0]		;Just Check two boundary conditions
	MOVE @++DP[0], A[15]   
	MOVE @++DP[0], ACC
	MOVE @++DP[0], A[AP]
	MOVE @++DP[0], IP
	MOVE @++DP[0], @SP--
	MOVE @++DP[0], SP
	MOVE @++DP[0], IV
	MOVE @++DP[0], LC[0]
	MOVE @++DP[0], LC[1]
	MOVE @++DP[0], @BP[OFFS++]
	MOVE @++DP[0], @BP[OFFS--]
	MOVE @++DP[0], OFFS
	MOVE @++DP[0], DPC
	MOVE @++DP[0], GR
	MOVE @++DP[0], GRL
	MOVE @++DP[0], BP
	MOVE @++DP[0], GRS
	MOVE @++DP[0], GRH
	MOVE @++DP[0], GRXL
	MOVE @++DP[0], FP
	MOVE @--DP[0], #01h
	MOVE @--DP[0], AP
	MOVE @--DP[0], APC
	MOVE @--DP[0], PSF
	MOVE @--DP[0], IC
	MOVE @--DP[0], IMR
	MOVE @--DP[0], SC
	MOVE @--DP[0], IIR
	MOVE @--DP[0], CKCN
	MOVE @--DP[0], WDCN
	MOVE @--DP[0], A[0]		;Just Check two boundary conditions
	MOVE @--DP[0], A[15]   
	MOVE @--DP[0], ACC
	MOVE @--DP[0], A[AP]
	MOVE @--DP[0], IP
	MOVE @--DP[0], @SP--
	MOVE @--DP[0], SP
	MOVE @--DP[0], IV
	MOVE @--DP[0], LC[0]
	MOVE @--DP[0], LC[1]
	MOVE @--DP[0], @BP[OFFS++]
	MOVE @--DP[0], @BP[OFFS--]
	MOVE @--DP[0], OFFS
	MOVE @--DP[0], DPC
	MOVE @--DP[0], GR
	MOVE @--DP[0], GRL
	MOVE @--DP[0], BP
	MOVE @--DP[0], GRS
	MOVE @--DP[0], GRH
	MOVE @--DP[0], GRXL
	MOVE @--DP[0], FP
	MOVE DP[0], #01h
	MOVE DP[0], AP
	MOVE DP[0], APC
	MOVE DP[0], PSF
	MOVE DP[0], IC
	MOVE DP[0], IMR
	MOVE DP[0], SC
	MOVE DP[0], IIR
	MOVE DP[0], CKCN
	MOVE DP[0], WDCN
	MOVE DP[0], A[0]		;Just Check two boundary conditions
	MOVE DP[0], A[15]   
	MOVE DP[0], ACC
	MOVE DP[0], A[AP]
	MOVE DP[0], IP
	MOVE DP[0], @SP--
	MOVE DP[0], SP
	MOVE DP[0], IV
	MOVE DP[0], LC[0]
	MOVE DP[0], LC[1]
	MOVE DP[0], @BP[OFFS++]
	MOVE DP[0], @BP[OFFS--]
	MOVE DP[0], OFFS
	MOVE DP[0], DPC
	MOVE DP[0], GR
	MOVE DP[0], GRL
	MOVE DP[0], BP
	MOVE DP[0], GRS
	MOVE DP[0], GRH
	MOVE DP[0], GRXL
	MOVE DP[0], FP
	MOVE SC, #01h
	MOVE SC, AP
	MOVE SC, APC
	MOVE SC, PSF
	MOVE SC, IC
	MOVE SC, IMR
	MOVE SC, IIR
	MOVE SC, CKCN
	MOVE SC, WDCN
	MOVE SC, A[0]		;Just Check two boundary conditions
	MOVE SC, A[15]   
	MOVE SC, ACC
	MOVE SC, A[AP]
	MOVE SC, IP
	MOVE SC, @SP--
	MOVE SC, SP
	MOVE SC, IV
	MOVE SC, LC[0]
	MOVE SC, LC[1]
	MOVE SC, @BP[OFFS++]
	MOVE SC, @BP[OFFS--]
	MOVE SC, OFFS
	MOVE SC, DPC
	MOVE SC, GR
	MOVE SC, GRL
	MOVE SC, BP
	MOVE SC, GRS
	MOVE SC, GRH
	MOVE SC, GRXL
	MOVE SC, FP
	MOVE SC, @DP[0]	
	MOVE SC, @DP[1]	
	MOVE SC, @DP[0]++		
	MOVE SC, @DP[1]++
	MOVE SC, @DP[0]--
	MOVE SC, @DP[1]--
	MOVE CKCN, #01h
	MOVE CKCN, AP
	MOVE CKCN, APC
	MOVE CKCN, PSF
	MOVE CKCN, IC
	MOVE CKCN, IMR
	MOVE CKCN, SC
	MOVE CKCN, IIR
	MOVE CKCN, WDCN
	MOVE CKCN, A[0]		;Just Check two boundary conditions
	MOVE CKCN, A[15]   
	MOVE CKCN, ACC
	MOVE CKCN, A[AP]
	MOVE CKCN, IP
	MOVE CKCN, @SP--
	MOVE CKCN, SP
	MOVE CKCN, IV
	MOVE CKCN, LC[0]
	MOVE CKCN, LC[1]
	MOVE CKCN, @BP[OFFS++]
	MOVE CKCN, @BP[OFFS--]
	MOVE CKCN, OFFS
	MOVE CKCN, DPC
	MOVE CKCN, GR
	MOVE CKCN, GRL
	MOVE CKCN, BP
	MOVE CKCN, GRS
	MOVE CKCN, GRH
	MOVE CKCN, GRXL
	MOVE CKCN, FP
	MOVE CKCN, @DP[0]	
	MOVE CKCN, @DP[1]	
	MOVE CKCN, @DP[0]++		
	MOVE CKCN, @DP[1]++
	MOVE CKCN, @DP[0]--
	MOVE CKCN, @DP[1]--
	MOVE A[0], #01h
	MOVE A[0], AP
	MOVE A[0], APC
	MOVE A[0], PSF
	MOVE A[0], IC
	MOVE A[0], IMR
	MOVE A[0], SC
	MOVE A[0], IIR
	MOVE A[0], CKCN
	MOVE A[0], WDCN
	MOVE A[0], ACC
	MOVE A[0], A[AP]
	MOVE A[0], IP
	MOVE A[0], @SP--
	MOVE A[0], SP
	MOVE A[0], IV
	MOVE A[0], LC[0]
	MOVE A[0], LC[1]
	MOVE A[0], @BP[OFFS++]
	MOVE A[0], @BP[OFFS--]
	MOVE A[0], OFFS
	MOVE A[0], DPC
	MOVE A[0], GR
	MOVE A[0], GRL
	MOVE A[0], BP
	MOVE A[0], GRS
	MOVE A[0], GRH
	MOVE A[0], GRXL
	MOVE A[0], FP
	MOVE A[0], @DP[0]	
	MOVE A[0], @DP[1]	
	MOVE A[0], @DP[0]++		
	MOVE A[0], @DP[1]++
	MOVE A[0], @DP[0]--
	MOVE A[0], @DP[1]--
	MOVE GRH, #01h
	MOVE GRH, AP
	MOVE GRH, APC
	MOVE GRH, PSF
	MOVE GRH, IC
	MOVE GRH, IMR
	MOVE GRH, SC
	MOVE GRH, IIR
	MOVE GRH, CKCN
	MOVE GRH, WDCN
	MOVE GRH, A[0]		;Just Check two boundary conditions
	MOVE GRH, A[15]   
	MOVE GRH, ACC
	MOVE GRH, A[AP]
	MOVE GRH, IP
	MOVE GRH, @SP--
	MOVE GRH, SP
	MOVE GRH, IV
	MOVE GRH, LC[0]
	MOVE GRH, LC[1]
	MOVE GRH, @BP[OFFS++]
	MOVE GRH, @BP[OFFS--]
	MOVE GRH, OFFS
	MOVE GRH, DPC
	MOVE GRH, GR
	MOVE GRH, GRL
	MOVE GRH, BP
	MOVE GRH, GRS
	MOVE GRH, GRXL
	MOVE GRH, FP
	MOVE GRH, @DP[0]	
	MOVE GRH, @DP[1]	
	MOVE GRH, @DP[0]++		
	MOVE GRH, @DP[1]++
	MOVE GRH, @DP[0]--
	MOVE GRH, @DP[1]--
