# Instruction with no operands.
 .data
foodata: .word 42
	 .text
footext:

	.global nop
nop:
nop

	.global retx
retx:
retx

	.global di
di:
di

	.global ei
ei:
ei

	.global wait
wait:
wait

	.global eiwait
eiwait:
eiwait
